import React, { Component } from 'react'
import {connect} from 'react-redux'
import {fetchPhones,loadMorePhones,addPhoneToBasket,fetchCategories} from 'actions'
import {getPhones} from 'selectors'
import {Link} from 'react-router-dom'
import * as R from 'ramda'
import Col from 'react-bootstrap/Col'
import Row from 'react-bootstrap/Row'
import Button from 'react-bootstrap/Button'
import Layout from 'containers/layout'
 class Phones extends Component {
   
    componentDidMount(){
        this.props.fetchPhones()
        this.props.fetchCategories()
    }
  

    renderPhone(phone, index) {
        const shortDescription = `${R.take(60, phone.description)}...`
        const {addPhoneToBasket} = this.props
        return (
            <Col sm={4} lg={4} md={4} key={index} >
            <div className='thumbnail'>
              <img
                className='img-thumbnail'
                src={phone.image}
                alt={phone.name}
              />
              <div className='caption'>
                <h4 className='pull-right'>${phone.price}</h4>
                <h4>
                  <Link to={`/phones/${phone.id}`}>
                    {phone.name}
                  </Link>
                </h4>
                <p>{shortDescription}</p>
                <p className='itemButton'>
                  <button className='btn btn-primary' onClick={() => addPhoneToBasket(phone.id)}>
                   Buy Now
                  </button>
                  <Link
                    to={`/phones/${phone.id}`}
                    className='btn btn-default'
                  >
                    More info
                  </Link>
                </p>
              </div>
            </div>
          </Col>
        )
      }


   render() {
    const {phones, loadMorePhones} = this.props
    return (
      <Layout>
      <div><Row>
        {phones.map((phone, index) => this.renderPhone(phone, index))}
      </Row>
      <Row>
     <Col md={12}>
     <Button onClick={loadMorePhones} variant="secondary" size="lg" block >Load More </Button>{' '}
     </Col>
     </Row>
     </div>
     </Layout>
    ) 
   }
    
}

const mapStateToProps = (state, ownProps) => ({
    phones: getPhones(state, ownProps)
})

const mapDispatchToProps = {
    fetchPhones,
    loadMorePhones,
    addPhoneToBasket,
    fetchCategories
}

export default connect(mapStateToProps, mapDispatchToProps)(Phones)